==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-session/lxqt-leave/lxqt-leave_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>LeaveDialog</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="29"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Cosa vuoi che faccia il computer?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="45"/>
        <source>Logout</source>
        <translation>Chiudi sessione</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="57"/>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="69"/>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="81"/>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="93"/>
        <source>Lock screen</source>
        <translation>Blocca lo schermo</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="105"/>
        <source>Hibernate</source>
        <translation>Iberna</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="136"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation>Chiusura della sessione.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation>Blocco dello schermo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation>Sospensione.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation>Ibernazione.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation>Spegnimento.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation>Riavvio.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-leave/lxqt-leave_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LeaveDialog</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Modulo</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="59"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Cosa vuoi che faccia il computer?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="92"/>
        <source>Logout</source>
        <translation>Chiudi sessione</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="206"/>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="186"/>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="139"/>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="112"/>
        <source>Lock screen</source>
        <translation>Blocca lo schermo</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="159"/>
        <source>Hibernate</source>
        <translation>Iberna</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="42"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation>Chiusura della sessione.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation>Blocco dello schermo.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation>Sospensione.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation>Ibernazione.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation>Spegnimento.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation>Riavvio.</translation>
    </message>
</context>
</TS>
